@@ -119,6 +119,7 @@ class Execution(
         "mode": "mode",
         "parameters": "parameters",
         "parent_execution_id": "parentExecutionId",
+        "resource_group_id": "resourceGroupId",
         "resource_options": "resourceOptions",
         "safety_check": "safetyCheck",
         "tags": "tags",
@@ -133,6 +134,7 @@ class ExecutionProps:
         mode: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         parameters: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Mapping[builtins.str, typing.Any]]] = None,
         parent_execution_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+        resource_group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         resource_options: typing.Optional[typing.Union[ros_cdk_core.IResolvable, "RosExecution.ResourceOptionsProperty"]] = None,
         safety_check: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         tags: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
@@ -144,6 +146,7 @@ class ExecutionProps:
         :param mode: Property mode: Execution mode.
         :param parameters: Property parameters: Parameters for the execution of template.
         :param parent_execution_id: Property parentExecutionId: Parent execution ID.
+        :param resource_group_id: Property resourceGroupId: Resource group id.
         :param resource_options: Property resourceOptions: Resource options user by ROS.
         :param safety_check: Property safetyCheck: Security check mode. Allowed values: - Skip: This option means that customers understand the risks, you can do anything without confirmation Action, no matter what the level of risk. It takes effect only if Mode is Automatic. - ConfirmEveryHighRiskAction (default): This option would require customers to confirm each Action a high risk. NotifyExecution by calling customer interface to confirm or cancel.
         :param tags: Property tags: Tag value and the key mapping, the label of the key number can be up to 20.
@@ -158,6 +161,8 @@ class ExecutionProps:
             self._values["parameters"] = parameters
         if parent_execution_id is not None:
             self._values["parent_execution_id"] = parent_execution_id
+        if resource_group_id is not None:
+            self._values["resource_group_id"] = resource_group_id
         if resource_options is not None:
             self._values["resource_options"] = resource_options
         if safety_check is not None:
@@ -201,6 +206,14 @@ class ExecutionProps:
         result = self._values.get("parent_execution_id")
         return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
 
+    @builtins.property
+    def resource_group_id(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+        '''Property resourceGroupId: Resource group id.'''
+        result = self._values.get("resource_group_id")
+        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
+
     @builtins.property
     def resource_options(
         self,
@@ -301,6 +314,7 @@ class Parameter(
         "value": "value",
         "constraints": "constraints",
         "description": "description",
+        "resource_group_id": "resourceGroupId",
     },
 )
 class ParameterProps:
@@ -312,6 +326,7 @@ class ParameterProps:
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
         constraints: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         description: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+        resource_group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
     ) -> None:
         '''Properties for defining a ``ALIYUN::OOS::Parameter``.
 
@@ -320,6 +335,7 @@ class ParameterProps:
         :param value: Property value: The value of the parameter. The value must be 1 to 4096 characters in length.
         :param constraints: Property constraints: The constraints of the parameter. By default, this parameter is null. Valid values: AllowedValues: The value that is allowed for the parameter. It must be an array string. AllowedPattern: The pattern that is allowed for the parameter. It must be a regular expression. MinLength: The minimum length of the parameter. MaxLength: The maximum length of the parameter.
         :param description: Property description: The description of the parameter. The description must be 1 to 200 characters in length.
+        :param resource_group_id: Property resourceGroupId: Resource group id.
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "name": name,
@@ -330,6 +346,8 @@ class ParameterProps:
             self._values["constraints"] = constraints
         if description is not None:
             self._values["description"] = description
+        if resource_group_id is not None:
+            self._values["resource_group_id"] = resource_group_id
 
     @builtins.property
     def name(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
@@ -388,6 +406,14 @@ class ParameterProps:
         result = self._values.get("description")
         return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
 
+    @builtins.property
+    def resource_group_id(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+        '''Property resourceGroupId: Resource group id.'''
+        result = self._values.get("resource_group_id")
+        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -596,6 +622,23 @@ class RosExecution(
     ) -> None:
         jsii.set(self, "parentExecutionId", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="resourceGroupId")
+    def resource_group_id(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+        '''
+        :Property: resourceGroupId: Resource group id.
+        '''
+        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], jsii.get(self, "resourceGroupId"))
+
+    @resource_group_id.setter
+    def resource_group_id(
+        self,
+        value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+    ) -> None:
+        jsii.set(self, "resourceGroupId", value)
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="resourceOptions")
     def resource_options(
@@ -773,6 +816,7 @@ class RosExecution(
         "mode": "mode",
         "parameters": "parameters",
         "parent_execution_id": "parentExecutionId",
+        "resource_group_id": "resourceGroupId",
         "resource_options": "resourceOptions",
         "safety_check": "safetyCheck",
         "tags": "tags",
@@ -787,6 +831,7 @@ class RosExecutionProps:
         mode: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         parameters: typing.Optional[typing.Union[ros_cdk_core.IResolvable, typing.Mapping[builtins.str, typing.Any]]] = None,
         parent_execution_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+        resource_group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         resource_options: typing.Optional[typing.Union[ros_cdk_core.IResolvable, RosExecution.ResourceOptionsProperty]] = None,
         safety_check: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         tags: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
@@ -798,6 +843,7 @@ class RosExecutionProps:
         :param mode: 
         :param parameters: 
         :param parent_execution_id: 
+        :param resource_group_id: 
         :param resource_options: 
         :param safety_check: 
         :param tags: 
@@ -812,6 +858,8 @@ class RosExecutionProps:
             self._values["parameters"] = parameters
         if parent_execution_id is not None:
             self._values["parent_execution_id"] = parent_execution_id
+        if resource_group_id is not None:
+            self._values["resource_group_id"] = resource_group_id
         if resource_options is not None:
             self._values["resource_options"] = resource_options
         if safety_check is not None:
@@ -860,6 +908,16 @@ class RosExecutionProps:
         result = self._values.get("parent_execution_id")
         return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
 
+    @builtins.property
+    def resource_group_id(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+        '''
+        :Property: resourceGroupId: Resource group id.
+        '''
+        result = self._values.get("resource_group_id")
+        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
+
     @builtins.property
     def resource_options(
         self,
@@ -1077,6 +1135,23 @@ class RosParameter(
     ) -> None:
         jsii.set(self, "description", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="resourceGroupId")
+    def resource_group_id(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+        '''
+        :Property: resourceGroupId: Resource group id.
+        '''
+        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], jsii.get(self, "resourceGroupId"))
+
+    @resource_group_id.setter
+    def resource_group_id(
+        self,
+        value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+    ) -> None:
+        jsii.set(self, "resourceGroupId", value)
+
 
 @jsii.data_type(
     jsii_type="@alicloud/ros-cdk-oos.RosParameterProps",
@@ -1087,6 +1162,7 @@ class RosParameter(
         "value": "value",
         "constraints": "constraints",
         "description": "description",
+        "resource_group_id": "resourceGroupId",
     },
 )
 class RosParameterProps:
@@ -1098,6 +1174,7 @@ class RosParameterProps:
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
         constraints: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         description: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+        resource_group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
     ) -> None:
         '''Properties for defining a ``ALIYUN::OOS::Parameter``.
 
@@ -1106,6 +1183,7 @@ class RosParameterProps:
         :param value: 
         :param constraints: 
         :param description: 
+        :param resource_group_id: 
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "name": name,
@@ -1116,6 +1194,8 @@ class RosParameterProps:
             self._values["constraints"] = constraints
         if description is not None:
             self._values["description"] = description
+        if resource_group_id is not None:
+            self._values["resource_group_id"] = resource_group_id
 
     @builtins.property
     def name(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
@@ -1184,6 +1264,16 @@ class RosParameterProps:
         result = self._values.get("description")
         return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
 
+    @builtins.property
+    def resource_group_id(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+        '''
+        :Property: resourceGroupId: Resource group id.
+        '''
+        result = self._values.get("resource_group_id")
+        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -1303,6 +1393,23 @@ class RosTemplate(
     ) -> None:
         jsii.set(self, "templateName", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="resourceGroupId")
+    def resource_group_id(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+        '''
+        :Property: resourceGroupId: Resource group id.
+        '''
+        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], jsii.get(self, "resourceGroupId"))
+
+    @resource_group_id.setter
+    def resource_group_id(
+        self,
+        value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+    ) -> None:
+        jsii.set(self, "resourceGroupId", value)
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="tags")
     def tags(self) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
@@ -1325,6 +1432,7 @@ class RosTemplate(
     name_mapping={
         "content": "content",
         "template_name": "templateName",
+        "resource_group_id": "resourceGroupId",
         "tags": "tags",
     },
 )
@@ -1334,18 +1442,22 @@ class RosTemplateProps:
         *,
         content: typing.Union[builtins.str, ros_cdk_core.IResolvable],
         template_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+        resource_group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         tags: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
     ) -> None:
         '''Properties for defining a ``ALIYUN::OOS::Template``.
 
         :param content: 
         :param template_name: 
+        :param resource_group_id: 
         :param tags: 
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "content": content,
             "template_name": template_name,
         }
+        if resource_group_id is not None:
+            self._values["resource_group_id"] = resource_group_id
         if tags is not None:
             self._values["tags"] = tags
 
@@ -1367,6 +1479,16 @@ class RosTemplateProps:
         assert result is not None, "Required property 'template_name' is missing"
         return typing.cast(typing.Union[builtins.str, ros_cdk_core.IResolvable], result)
 
+    @builtins.property
+    def resource_group_id(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+        '''
+        :Property: resourceGroupId: Resource group id.
+        '''
+        result = self._values.get("resource_group_id")
+        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
+
     @builtins.property
     def tags(self) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
         '''
@@ -1439,6 +1561,7 @@ class Template(
     name_mapping={
         "content": "content",
         "template_name": "templateName",
+        "resource_group_id": "resourceGroupId",
         "tags": "tags",
     },
 )
@@ -1448,18 +1571,22 @@ class TemplateProps:
         *,
         content: typing.Union[builtins.str, ros_cdk_core.IResolvable],
         template_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+        resource_group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         tags: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
     ) -> None:
         '''Properties for defining a ``ALIYUN::OOS::Template``.
 
         :param content: Property content: The content of the template. The template must be in the JSON or YAML format. Maximum size: 64 KB.
         :param template_name: Property templateName: The name of the template. The template name can be up to 200 characters in length. The name can contain letters, digits, hyphens (-), and underscores (_). It cannot start with ALIYUN, ACS, ALIBABA, or ALICLOUD.
+        :param resource_group_id: Property resourceGroupId: Resource group id.
         :param tags: Property tags: Tag value and the key mapping, the label of the key number can be up to 20.
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "content": content,
             "template_name": template_name,
         }
+        if resource_group_id is not None:
+            self._values["resource_group_id"] = resource_group_id
         if tags is not None:
             self._values["tags"] = tags
 
@@ -1483,6 +1610,14 @@ class TemplateProps:
         assert result is not None, "Required property 'template_name' is missing"
         return typing.cast(typing.Union[builtins.str, ros_cdk_core.IResolvable], result)
 
+    @builtins.property
+    def resource_group_id(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+        '''Property resourceGroupId: Resource group id.'''
+        result = self._values.get("resource_group_id")
+        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
+
     @builtins.property
     def tags(self) -> typing.Optional[typing.Mapping[builtins.str, typing.Any]]:
         '''Property tags: Tag value and the key mapping, the label of the key number can be up to 20.'''
